Introduction
============
In the same way Pathway Commons was successful at combining many molecular pathway and interaction database, BEL has
the potential to serve as a semantic integration platform through which knowledge and data across scales can be
integrated and analyzed. BEL has already been used to reason over the previously untapped sources of chemogenomic and
chemical genetic information [1]_ and can be extended further into the realm of disease-disease,
disease-protein, disease-chemical, and chemical-chemical networks.

Citations
---------
.. [1] Emon, M. A. E. K., *et al.* (2017). `Using Drugs as Molecular Probes: A Computational Chemical Biology Approach
       in Neurodegenerative Diseases <https://doi.org/10.3233/JAD-160222>`_. Journal of Alzheimer’s Disease, 56(2),
       677–686.
